class PersonalBooksController < ApplicationController
  def index
    params = OrbitHelper.params
    books = Book.where(:is_hidden=>false).sort_for_frontend.page(OrbitHelper.params[:page_no]).per(OrbitHelper.page_data_count)
    page = Page.where(:page_id => params[:page_id]).first rescue nil

    if page.custom_string_field == "table"
      fields_to_show = page.custom_array_field rescue []
      fields_to_show = [
        "authors",
        "book_title",
        "extracted_chapters",
        "publisher",
        "isbn",
        "publish_date"
      ] if fields_to_show.blank?
    else
      fields_to_show = [
        "year",
        "book_title"
      ]
    end

    book_list = []
    books.each do |book|
      t = []
      fields_to_show.each do |fs|
        case fs
        when "book_title", "extracted_chapters"
          if  page.custom_string_field == "table"
           t << {"value" => "<a href='#{OrbitHelper.url_to_show(book.to_param)}'>#{book.send(fs)}</a>"}
          else
           t << {"value" => "<a href='#{OrbitHelper.url_to_show(book.to_param)}'>#{book.create_link}</a>"}
          end
        when "publish_date", "publication_date"
          pd = ""
          if !book.publication_date.nil?
            pd = book.publication_date.strftime("%Y-%m-%d").split('-')
            pd = pd[0]+"/"+pd[1]
          end
          t << {"value" => pd}
        when "author_type"
          t << {"value" => (book.book_author_types.collect{|bat| bat.title}.join(", ") rescue "")}
        when "language"
          t << {"value" => (I18n.t("personal_book.#{book.language}") if !book.language.nil? rescue "")}
        else
          t << {"value" => book.send(fs)}
        end
      end
      book_list << {"books" => t}
    end

    headers = []
    fields_to_show.each do |fs|
      col = 2
      col = 3 if fs == "paper_title"
      headers << {
        "head-title" => t("personal_book.#{fs}"),
        "col" => col
      }
    end
    {
      "book_list" => book_list,
      "extras" => {"widget-title" => t("module_name.book")},
      "headers" => headers,
      "total_pages" => books.total_pages
    }
  end

  def show
    params = OrbitHelper.params
    plugin = Book.where(:is_hidden=>false).find_by(uid: params[:uid])
    fields_to_show = [
      "year",
      "book_title",
      "authors",
      "book_paper_type",
      "extracted_chapters",
      "publisher",
      "publish_date",
      "pages",
      "editor",
      "author_type",
      "number_of_authors", 
      "isbn",
      "url",
      "publication_date",
      "language"
    ]

    {"plugin_datas"=>plugin.get_plugin_data(fields_to_show)}
  end

  def get_fields_for_index
    @page = Page.find(params[:page_id]) rescue nil
    @fields_to_show = [
      "year",
      "book_title",
      "authors",
      "book_paper_type",
      "extracted_chapters",
      "publisher",
      "publish_date",
      "pages",
      "editor",
      "author_type",
      "number_of_authors", 
      "isbn",
      "url",
      "file",
      "publication_date",
      "language"
    ]
    @fields_to_show = @fields_to_show.map{|fs| [t("personal_book.#{fs}"), fs]}
    @default_fields_to_show = [
      "authors",
      "book_title",
      "extracted_chapters",
      "publisher",
      "isbn",
      "publish_date"
    ]
    render :layout => false
  end

  def save_index_fields
    page = Page.find(params[:page_id]) rescue nil
    page.custom_array_field = params[:keys]
    page.save
    render :json => {"success" => true}.to_json
  end
end
